'use strict';

var css = require('@master/css');
var vscodeLanguageserverProtocol = require('vscode-languageserver-protocol');
var sortCompletionItems = require('./sort-completion-items.cjs');

function getColorCompletionItems(css$1 = new css.MasterCSS()) {
    const completionItems = [];
    css$1.variables.forEach((eachVariable, eachVariableName)=>{
        if (eachVariable.type === 'color') {
            // todo: packages/core should support getTextByVariable(variable)
            const valueToken = eachVariable.space && eachVariable.value ? `${eachVariable.space}(${eachVariable.value})` : eachVariable.value;
            completionItems.push({
                label: eachVariableName,
                // detail is shown in the detail pane
                // todo: eachVariable.token should be recorded as original config variable
                detail: valueToken,
                // documentation is shown in the hover
                // todo: should convert and space to rgba
                documentation: eachVariable.space && eachVariable.value ? `${eachVariable.space}(${eachVariable.value.split(' ').join(',')})` : eachVariable.value,
                kind: vscodeLanguageserverProtocol.CompletionItemKind.Color,
                sortText: eachVariableName.replace(/(.+?)-(\d+)/, (match, prefix, num)=>prefix + '-' + ('00000' + num).slice(-5))
            });
        }
    });
    return sortCompletionItems(completionItems);
}

module.exports = getColorCompletionItems;
