'use strict';

var css = require('@master/css');
var vscodeLanguageserverProtocol = require('vscode-languageserver-protocol');
var sortCompletionItems = require('./sort-completion-items.cjs');
var getCssDataDocumentation = require('./get-css-data-documentation.cjs');
var cssDataProvider = require('./css-data-provider.cjs');

function getQueryCompletionItems(css$1 = new css.MasterCSS(), triggerCharacter = css.AT_SIGN, syntax) {
    const atDataList = cssDataProvider.provideAtDirectives();
    const completionItems = [];
    if (!css.QUERY_COMPARISON_OPERATORS.includes(triggerCharacter)) {
        completionItems.push({
            label: triggerCharacter + 'media()',
            filterText: 'media()',
            insertText: 'media()',
            sortText: 'media()',
            documentation: getCssDataDocumentation.getCSSDataDocumentation(atDataList.find(({ name })=>name === '@media'), {
                generatedCSS: css.generateCSS([
                    syntax + 'media()'
                ], css$1),
                docs: '/guide/syntax#at-rules'
            })
        }, {
            label: triggerCharacter + 'supports()',
            filterText: 'supports()',
            insertText: 'supports()',
            sortText: 'supports()',
            documentation: getCssDataDocumentation.getCSSDataDocumentation(atDataList.find(({ name })=>name === '@supports'), {
                generatedCSS: css.generateCSS([
                    syntax + 'supports()'
                ], css$1),
                docs: '/guide/syntax#at-rules'
            })
        });
    }
    css$1.at.forEach((value, name)=>{
        const completionItem = {
            filterText: name,
            insertText: name,
            documentation: getCssDataDocumentation.getCSSDataDocumentation(undefined, {
                generatedCSS: css.generateCSS([
                    syntax + name
                ], css$1),
                docs: '/guide/syntax#at-rules'
            })
        };
        if ([
            css.AT_SIGN,
            ...css.QUERY_LOGICAL_OPERATORS
        ].includes(triggerCharacter)) {
            if (typeof value === 'number') {
                completionItems.push({
                    ...completionItem,
                    label: triggerCharacter + name,
                    sortText: String(value).padStart(8, '0'),
                    filterText: name,
                    insertText: name,
                    documentation: getCssDataDocumentation.getCSSDataDocumentation(undefined, {
                        generatedCSS: css.generateCSS([
                            syntax + name
                        ], css$1),
                        docs: '/guide/syntax#at-rules'
                    }),
                    detail: `screen width ${'>='} ${value}px`,
                    kind: vscodeLanguageserverProtocol.CompletionItemKind.Keyword
                });
            } else {
                completionItems.push({
                    ...completionItem,
                    label: triggerCharacter + name,
                    detail: value,
                    sortText: name,
                    kind: vscodeLanguageserverProtocol.CompletionItemKind.Keyword
                });
            }
        } else if (css.QUERY_COMPARISON_OPERATORS.includes(triggerCharacter)) {
            if (typeof value === 'number') {
                const prevComparisonCharacter = syntax.charAt(syntax.length - 2);
                const comparisonCharacter = prevComparisonCharacter === '>' || prevComparisonCharacter === '<' ? prevComparisonCharacter + triggerCharacter : triggerCharacter;
                completionItems.push({
                    ...completionItem,
                    label: comparisonCharacter + name,
                    sortText: comparisonCharacter + String(value).padStart(8, '0'),
                    filterText: name,
                    insertText: name,
                    documentation: getCssDataDocumentation.getCSSDataDocumentation(undefined, {
                        generatedCSS: css.generateCSS([
                            syntax + name
                        ], css$1),
                        docs: '/guide/syntax#at-rules'
                    }),
                    detail: `screen width ${comparisonCharacter} ${value}px`,
                    kind: vscodeLanguageserverProtocol.CompletionItemKind.Keyword
                });
            }
        }
    });
    return sortCompletionItems(completionItems);
}

module.exports = getQueryCompletionItems;
